@@ -2,6 +2,7 @@ from vade_api_src.vade_enums import *
 from datetime import datetime
 from dateutil import parser
 from enum import Enum
+import webcolors
 
 class GeoPoint:
     lat: float
@@ -86,20 +87,37 @@ class DefaultGeoPoints:
 
 class VadeVehicleType(Enum):
     SUV = "SUV"
-    SEDAN = "sedan"
+    SEDAN = 'sedan'
     MINIVAN = 'minivan'
     MPV = "MPV"
     LARGE_TRUCK = "large truck"
     LARGE_BUS = "large-sized bus"
     LIGHT_PASSENGER_VEHICLE = "light passenger vehicle"
     PICKUP_TRUCK = "pickup truck"
+    SMALL_TRUCK = " small-sized truck"
+    OTHER = "other"
+
 
     @staticmethod
     def from_str(str_val: str):
         try:
-            return VadeVehicleType[str_val]
+            return VadeVehicleType[str_val.upper()]
         except Exception as e:
-            return None
+            try:
+                return VadeVehicleType[str_val.lower()]
+            except:
+                if str_val == "large truck":
+                    return VadeVehicleType.LARGE_TRUCK
+                if str_val == "large-sized bus":
+                    return VadeVehicleType.LARGE_BUS
+                if str_val == "light passenger vehicle":
+                    return VadeVehicleType.LIGHT_PASSENGER_VEHICLE
+                if str_val == "pickup truck":
+                    return VadeVehicleType.PICKUP_TRUCK
+                if str_val == " small-sized truck":
+                    return  VadeVehicleType.SMALL_TRUCK
+                else:
+                    return None
 
 
 class TypeOption:
@@ -140,6 +158,21 @@ class ColorOption:
         ret_val = {"color": self.color, "weight": self.weight}
         return ret_val
 
+    def color_name(self):
+        try:
+            h = self.color.lstrip('#')
+            rgb_val = tuple(int(h[i:i + 2], 16) for i in (0, 2, 4))
+            min_colours = {}
+            for key, name in webcolors.CSS3_HEX_TO_NAMES.items():
+                r_c, g_c, b_c = webcolors.hex_to_rgb(key)
+                rd = (r_c - rgb_val[0]) ** 2
+                gd = (g_c - rgb_val[1]) ** 2
+                bd = (b_c - rgb_val[2]) ** 2
+                min_colours[(rd + gd + bd)] = name
+            return min_colours[min(min_colours.keys())]
+        except:
+            return None
+
 
 class VadeSpotVehicleDetails:
     color_options: [ColorOption] = []
@@ -152,7 +185,7 @@ class VadeSpotVehicleDetails:
             new.color_options = []
             new.vehicle_type_options = []
             try:
-                color_ops_raw = j["color"]
+                color_ops_raw = j["colors"]
                 for option in color_ops_raw:
                     new_color = ColorOption.from_json(option)
                     if new_color:
